@@ -9,9 +9,8 @@ use TAP::Parser::Aggregator;
 use YAML::Syck;
 use Data::Dumper;
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
-# plain function approach
 sub new {
         # hash or hash ref
         my $class = shift;
@@ -23,8 +22,11 @@ sub new {
         my @pragmas;
         my $bailout;
 
-        my %IGNORE = map { $_ => 1 } @{$args{ignore}};
+        my %IGNORE      = map { $_ => 1 } @{$args{ignore}};
+        my $IGNORELINES = $args{ignorelines};
         delete $args{ignore};
+        delete $args{ignorelines};
+
         my $parser = new TAP::Parser( { %args } );
 
         my $aggregate = new TAP::Parser::Aggregator;
@@ -33,6 +35,8 @@ sub new {
         while ( my $result = $parser->next ) {
                 no strict 'refs';
 
+                next if $IGNORELINES && $result->raw =~ m/$IGNORELINES/;
+
                 my %entry = ();
 
                 # test info
@@ -154,8 +158,9 @@ change, so your data tools can, well, rely on it.
 Constructor which immediately triggers parsing the TAP via TAP::Parser
 and returns a big data structure containing the extracted results.
 
-All parameters (except C<ignore>, see section "HOW TO STRIP DETAILS")
-are passed through to TAP::Parser. Usually just one of those:
+All parameters (except C<ignore> and C<ignorelines>, see section "HOW
+TO STRIP DETAILS") are passed through to TAP::Parser. Usually just one
+of those:
 
   tap => $some_tap_string
 
@@ -351,9 +356,13 @@ belong.
 =head1 HOW TO STRIP DETAILS
 
 You can make the DOM a bit more terse (i.e., less blown up) if you do
-not need every detail. For this provide the C<ignore> option to
-new(). It is an array ref specifying keys that should not be contained
-in the TAP-DOM. Currently supported are:
+not need every detail.
+
+=head2 Strip unneccessary TAP-DOM fields
+
+For this provide the C<ignore> option to new(). It is an array ref
+specifying keys that should not be contained in the TAP-DOM. Currently
+supported are:
 
  has_todo
  has_skip
@@ -383,6 +392,24 @@ Use it like this:
                             ignore => [ qw( raw as_string ) ],
                            );
 
+=head2 Strip unneccessary lines
+
+You can ignore complete lines from the input TAP as if they weren't
+existing. Of course you can break the TAP with this, so usually you
+only apply this to non-TAP lines or diagnostics you are not interested
+in.
+
+My primary use-case is TAP with large parts of logfiles included with
+a prefixed "## " just for dual-using the TAP also as an archive of the
+log. When evaluating the TAP later I leave those log lines out because
+they only blow up the memory for the TAP-DOM:
+
+   $tapdom = TAP::DOM->new (tap         => $tap,
+                            ignorelines => qr/^## /,
+                           );
+
+See C<t/some_tap_ignore_lines.t> for an example.
+
 =head1 AUTHOR
 
 Steffen Schwigon, C<< <schwigon at cpan.org> >>
